function [trace]= extract(file)

% this function reads a miniseed file, checks for gaps, double entries
% a low pass of 1 s is administered to avoid aliasing effects

% usage:
% file: mseed file

% Copyright 2016 M.Reiss and G.Rümpker

% read miniseed file
[X,I] = rdmseed(file);

for i_comp=1:length(I)
    
    clear comp_name
    clear comp
    clear trace0
    clear dtfigure
    clear t
    clear DupIndex
    
    comp_name = I(i_comp).ChannelFullName;
    comp = I(i_comp).XBlockIndex;
    
    trace0 = cat(1,X(comp).d);
    trace0 = trace0-mean(trace0);
    dt = 1/X(i_comp).SampleRate;
    t = cat(1,X(comp).t);
    
    %% check if gaps exist
    if isempty(I(i_comp).GapBlockIndex)
        
        %% sort time and amp values, delete multiples
        
        [new_t, ind_sort] = sort(t);
        new_trace = trace0(ind_sort);
        
        A = [new_t';new_trace']';
        
        [~,Index] = unique(A,'rows','first');
        
        DupIndex = setdiff(1:size(A,1),Index);
        A(DupIndex,:) = [];
        new_t = A(:,1)';
        new_trace = A(:,2)';
        
        t = new_t;
        trace0 = new_trace;
               
        % low pass butterworth filter
        trace0 = buttern_low(trace0,6,1,dt);
        
    else
        disp('data points are missing')
        trace0 = 0;
        t = 0;
        dt = 0;
    end
    
    % use appropriate channel name
    if strfind(comp_name,'HE') 
        trace(1).comp = 'East';
        trace(1).amp = trace0;
        trace(1).time = t;
        trace(1).dt = dt;
    end
    if strfind(comp_name,'HN') 
        trace(2).comp = 'North';
        trace(2).amp = trace0;
        trace(2).time = t;
        trace(2).dt = dt;
    end
    if strfind(comp_name,'HZ') 
        trace(3).comp = 'Z';
        trace(3).amp = trace0;
        trace(3).time = t;
        trace(3).dt = dt;
    end
    
end

end